==> qore-1.0.12.tar.bz2: qore-1.0.12/docs/library/html/_restrictions_8h.js <==
var _restrictions_8h =
[
    [ "PO_ALLOW_BARE_REFS", "_restrictions_8h.html#a02d912e1c84d3cd5cfa98241bf45dec7", null ],
    [ "PO_ALLOW_DEBUGGER", "_restrictions_8h.html#a37fa8dc66e8999ad98195259090bcfee", null ],
    [ "PO_ALLOW_INJECTION", "_restrictions_8h.html#a5da129fbaddc363f0a6009fe0693542b", null ],
    [ "PO_ALLOW_RETURNS", "_restrictions_8h.html#a869a842c7f09f26c4ecc627e135d6845", null ],
    [ "PO_ALLOW_STATEMENT_NO_EFFECT", "_restrictions_8h.html#a8652634e0ae9d2a42b0637dd7381dfec", null ],
    [ "PO_ALLOW_WEAK_REFERENCES", "_restrictions_8h.html#a2947d036765cfc3a05b42b4fc9378fde", null ],
    [ "PO_ASSUME_LOCAL", "_restrictions_8h.html#a81f834652f26955dab9825221575c5c2", null ],
    [ "PO_BROKEN_CAST", "_restrictions_8h.html#a91541469e9dadaa2a48c1dc567b52482", null ],
    [ "PO_BROKEN_INT_ASSIGNMENTS", "_restrictions_8h.html#a3eddf2d51c0f63466d8484306be8894e", null ],
    [ "PO_BROKEN_LIST_PARSING", "_restrictions_8h.html#a97bc649950875191a1fe21b479624b40", null ],
    [ "PO_BROKEN_LOGIC_PRECEDENCE", "_restrictions_8h.html#a7f95f791b947dcee3c08196de5b31e6f", null ],
    [ "PO_BROKEN_LOOP_STATEMENT", "_restrictions_8h.html#a6529d08dacb020f44aa1dc65af9bfff2", null ],
    [ "PO_BROKEN_OPERATORS", "_restrictions_8h.html#a8f864618a956ab4e269ce683d2f22faf", null ],
    [ "PO_BROKEN_RANGE", "_restrictions_8h.html#a074963cba07cc02a0e7e1ceb2bb4e2a7", null ],
    [ "PO_BROKEN_REFERENCES", "_restrictions_8h.html#a20d1a4e4e60852fe6f679895d5492937", null ],
    [ "PO_BROKEN_SPRINTF", "_restrictions_8h.html#a3bdb6d77a5bd550a82f21e1ae9d80268", null ],
    [ "PO_DEFAULT", "_restrictions_8h.html#aa29860ef8e86f49c053eb01cd5970785", null ],
    [ "PO_FREE_OPTIONS", "_restrictions_8h.html#a8c0f832463cc90cbe0cdbbc971960d04", null ],
    [ "PO_IN_MODULE", "_restrictions_8h.html#a12e6461a371949633ac1f7446e703048", null ],
    [ "PO_INHERITANCE_OPTIONS", "_restrictions_8h.html#a30c8182ffe5352646dda65c51c6497d1", null ],
    [ "PO_LOCK_WARNINGS", "_restrictions_8h.html#af1d6283a0f6083095c5d282cd9ace342", null ],
    [ "PO_LOCKDOWN", "_restrictions_8h.html#a1c08b472c7971d53ef60d85491bdaed9", null ],
    [ "PO_NEW_STYLE", "_restrictions_8h.html#ae841c2af8dd20a22e2a7b53042570048", null ],
    [ "PO_NO_API", "_restrictions_8h.html#acd1cf6607929a5bfc48cc24870b14560", null ],
    [ "PO_NO_CHILD_PO_RESTRICTIONS", "_restrictions_8h.html#a561311c0f5f88c6e1d4eff677713bf19", null ],
    [ "PO_NO_CLASS_DEFS", "_restrictions_8h.html#a8b35d8d51093f6dd05266bc154a4e7dd", null ],
    [ "PO_NO_CONSTANT_DEFS", "_restrictions_8h.html#aaea207ef2850b46e28ae674151204c74", null ],
    [ "PO_NO_DATABASE", "_restrictions_8h.html#a59dfc5931d0eae676a2089f8e297ad80", null ],
    [ "PO_NO_DEBUGGING", "_restrictions_8h.html#aa15196fde657a2ef7ebd7318c40f12bb", null ],
    [ "PO_NO_EMBEDDED_LOGIC", "_restrictions_8h.html#adccf8054fcef8d07014fc27bb88e6b86", null ],
    [ "PO_NO_EXTERNAL_ACCESS", "_restrictions_8h.html#ab3983de451090bf2239f2a25fe38f73d", null ],
    [ "PO_NO_EXTERNAL_INFO", "_restrictions_8h.html#a72d368402cf8e9f6c8dafb74eee28745", null ],
    [ "PO_NO_EXTERNAL_PROCESS", "_restrictions_8h.html#a1ed3a8292c999e527115dcb68933c749", null ],
    [ "PO_NO_FILESYSTEM", "_restrictions_8h.html#abad0cbc4235b102f1ecaaffdbd6ebfa8", null ],
    [ "PO_NO_GLOBAL_VARS", "_restrictions_8h.html#a2e36e5f620fdb1f1a2382d1efe052025", null ],
    [ "PO_NO_GUI", "_restrictions_8h.html#a1d44fce931d36b4e4409f488d5648f1e", null ],
    [ "PO_NO_INHERIT_GLOBAL_VARS", "_restrictions_8h.html#abd55cb2825e3f0a862e617f877dd2168", null ],
    [ "PO_NO_INHERIT_PROGRAM_DATA", "_restrictions_8h.html#af40775b2d435f6461a3326e9cc484ff5", null ],
    [ "PO_NO_INHERIT_SYSTEM_CLASSES", "_restrictions_8h.html#a8be8cea4dd7ec9eb8687d9e682bece05", null ],
    [ "PO_NO_INHERIT_SYSTEM_CONSTANTS", "_restrictions_8h.html#a45a54df35963514ce26828c900c9b3ea", null ],
    [ "PO_NO_INHERIT_SYSTEM_FUNC_VARIANTS", "_restrictions_8h.html#af658e6d81da7de9272794dc71c0732d1", null ],
    [ "PO_NO_INHERIT_SYSTEM_HASHDECLS", "_restrictions_8h.html#a770b9c0f9234fad9a0d5fb725acde714", null ],
    [ "PO_NO_INHERIT_USER_CLASSES", "_restrictions_8h.html#ab133c826fe7a2e9529e30e8049da1586", null ],
    [ "PO_NO_INHERIT_USER_CONSTANTS", "_restrictions_8h.html#a51aa0fd43b74349a9204ae4e69d18cd8", null ],
    [ "PO_NO_INHERIT_USER_FUNC_VARIANTS", "_restrictions_8h.html#a68c67e66c5fb2041a598f46ade856573", null ],
    [ "PO_NO_INHERIT_USER_HASHDECLS", "_restrictions_8h.html#a29b2684994e069edf8d7048aee3e815c", null ],
    [ "PO_NO_IO", "_restrictions_8h.html#af1243d2900dbe34d3449134059d19393", null ],
    [ "PO_NO_LOCALE_CONTROL", "_restrictions_8h.html#a07a11f2168014dbb3583cbb008627336", null ],
    [ "PO_NO_MODULES", "_restrictions_8h.html#a8ba741a507c7ef6dd177574ea7b69b4c", null ],
    [ "PO_NO_NAMESPACE_DEFS", "_restrictions_8h.html#a16733571d13cb9ca375fe81b6f8f8d5e", null ],
    [ "PO_NO_NETWORK", "_restrictions_8h.html#a10a7a876290b7db60373b385c84e2b2c", null ],
    [ "PO_NO_NEW", "_restrictions_8h.html#a58296bea17ebf1413f097197a47e1201", null ],
    [ "PO_NO_PROCESS_CONTROL", "_restrictions_8h.html#af04c9ca44fb8283e3a93cbc00a0cdd9c", null ],
    [ "PO_NO_REFLECTION", "_restrictions_8h.html#aeb6b58dc32d5a70a9c40cffe8f135164", null ],
    [ "PO_NO_SUBROUTINE_DEFS", "_restrictions_8h.html#a5502e33cad308e81493e596589550afd", null ],
    [ "PO_NO_SYSTEM_API", "_restrictions_8h.html#ab541ab4240125bc9d690272469504675", null ],
    [ "PO_NO_TERMINAL_IO", "_restrictions_8h.html#aaaef27fa15c565cf9d24844838246d33", null ],
    [ "PO_NO_THREAD_CLASSES", "_restrictions_8h.html#a93cd5b824a585af6c31e687e9e065058", null ],
    [ "PO_NO_THREAD_CONTROL", "_restrictions_8h.html#afcd810858334ffcf57d20cf6ed5ccac3", null ],
    [ "PO_NO_THREAD_INFO", "_restrictions_8h.html#aa80b1d4932a471a343ffbc7494ae88e4", null ],
    [ "PO_NO_THREADS", "_restrictions_8h.html#a1e7e664d3055d0c361f6c8fb179174f4", null ],
    [ "PO_NO_TOP_LEVEL_STATEMENTS", "_restrictions_8h.html#a11d2724d7e2a46c0527f5434e4c6d93e", null ],
    [ "PO_NO_TRANSIENT", "_restrictions_8h.html#a5f8371658499be807982a79325577838", null ],
    [ "PO_NO_UNCONTROLLED_APIS", "_restrictions_8h.html#a04b2233f363e4f4c09d48305553d00ef", null ],
    [ "PO_NO_USER_API", "_restrictions_8h.html#a4a63d2f23a687c7a92e08a571725e81e", null ],
    [ "PO_POSITIVE_OPTIONS", "_restrictions_8h.html#a6b930298bc8fe27a2447159282b2b629", null ],
    [ "PO_REQUIRE_BARE_REFS", "_restrictions_8h.html#af11f1b7df14cb1468a4837d1572d8853", null ],
    [ "PO_REQUIRE_OUR", "_restrictions_8h.html#a75b1e59c3519cd7ac7dc5aa98ad89b90", null ],
    [ "PO_REQUIRE_PROTOTYPES", "_restrictions_8h.html#a7ea1ecb0e9ac1cb23def202970a99ec5", null ],
    [ "PO_REQUIRE_TYPES", "_restrictions_8h.html#a29e1813487b54afcc59a01a84e7f3d1c", null ],
    [ "PO_STRICT_ARGS", "_restrictions_8h.html#ab557b85e04e1d5eb44f843b5266dff7c", null ],
    [ "PO_STRICT_BOOLEAN_EVAL", "_restrictions_8h.html#a8f78f79e11e3dfc40903add2271eb57e", null ],
    [ "PO_STRICT_TYPES", "_restrictions_8h.html#a2b20bc9123f5fec8546f54f98461fc44", null ],
    [ "PO_STRONG_ENCAPSULATION", "_restrictions_8h.html#ae09562df3ae2b88c3f5ef1ec4a79ceb1", null ],
    [ "PO_SYSTEM_INHERITANCE_OPTIONS", "_restrictions_8h.html#a728b8373cf64adcc580806973e9d29fd", null ],
    [ "PO_SYSTEM_OPS", "_restrictions_8h.html#af6ae5a9da8d957f60bd63e84a3497197", null ],
    [ "PO_USER_INHERITANCE_OPTIONS", "_restrictions_8h.html#ab8a32efa6e09cf9c05c36a4da3328498", null ],
    [ "QDOM_DATABASE", "_restrictions_8h.html#af3533380f84f249d240684460a9291af", null ],
    [ "QDOM_DEBUGGER", "_restrictions_8h.html#ae23ea571fe599dc479fc9eb31083dc68", null ],
    [ "QDOM_DEFAULT", "_restrictions_8h.html#a26ce6266c308424920287f9da71cd524", null ],
    [ "QDOM_EMBEDDED_LOGIC", "_restrictions_8h.html#aac381340bae7ad204f78913c1c6b7b45", null ],
    [ "QDOM_EXTERNAL_INFO", "_restrictions_8h.html#a1a90042832295becc3b0d2c901a905b2", null ],
    [ "QDOM_EXTERNAL_PROCESS", "_restrictions_8h.html#a50b19ce6812e40399390eacf30a46aa3", null ],
    [ "QDOM_FILESYSTEM", "_restrictions_8h.html#a9add0f0463bc97396f7d40616d59b4c0", null ],
    [ "QDOM_GUI", "_restrictions_8h.html#aacc94472e85f38b49f1e65a66517fd66", null ],
    [ "QDOM_IN_MODULE", "_restrictions_8h.html#a9dd22458662f21465e77728c9f4c307e", null ],
    [ "QDOM_INJECTION", "_restrictions_8h.html#aad5a5b48b25980869d022e334e56f107", null ],
    [ "QDOM_LOCALE_CONTROL", "_restrictions_8h.html#a3678bcb5f709474c6962277d0bd73a8d", null ],
    [ "QDOM_MODULES", "_restrictions_8h.html#a59588ea01ce8d9795ff97557faf63fdd", null ],
    [ "QDOM_NETWORK", "_restrictions_8h.html#a56e52f68ab80aace1af16033060a5586", null ],
    [ "QDOM_PROCESS", "_restrictions_8h.html#ae02e056ea1a514e8e2bb729213132e44", null ],
    [ "QDOM_REFLECTION", "_restrictions_8h.html#a35637a04eb31e30d37e05b5e3ecb7460", null ],
    [ "QDOM_TERMINAL_IO", "_restrictions_8h.html#a595110baae5a7009a6b3b7d9d5f62e7a", null ],
    [ "QDOM_THREAD_CLASS", "_restrictions_8h.html#a70755201f6b17fa930daf3e5c362bc59", null ],
    [ "QDOM_THREAD_CONTROL", "_restrictions_8h.html#a7d5eba55a801d770a223ba6147652050", null ],
    [ "QDOM_THREAD_INFO", "_restrictions_8h.html#a3a9a03fccbbfecdd7832c3be37307a6d", null ],
    [ "QDOM_UNCONTROLLED_API", "_restrictions_8h.html#a231fb22b03c34eacb9811209456e7ae2", null ]
];

==> qore-1.14.2.tar.bz2: qore-1.14.2/docs/library/html/_restrictions_8h.js <==
var _restrictions_8h =
[
    [ "PO_ALLOW_BARE_REFS", "_restrictions_8h.html#a02d912e1c84d3cd5cfa98241bf45dec7", null ],
    [ "PO_ALLOW_DEBUGGER", "_restrictions_8h.html#a37fa8dc66e8999ad98195259090bcfee", null ],
    [ "PO_ALLOW_INJECTION", "_restrictions_8h.html#a5da129fbaddc363f0a6009fe0693542b", null ],
    [ "PO_ALLOW_RETURNS", "_restrictions_8h.html#a869a842c7f09f26c4ecc627e135d6845", null ],
    [ "PO_ALLOW_STATEMENT_NO_EFFECT", "_restrictions_8h.html#a8652634e0ae9d2a42b0637dd7381dfec", null ],
    [ "PO_ALLOW_WEAK_REFERENCES", "_restrictions_8h.html#a2947d036765cfc3a05b42b4fc9378fde", null ],
    [ "PO_ASSUME_LOCAL", "_restrictions_8h.html#a81f834652f26955dab9825221575c5c2", null ],
    [ "PO_BROKEN_CAST", "_restrictions_8h.html#a91541469e9dadaa2a48c1dc567b52482", null ],
    [ "PO_BROKEN_INT_ASSIGNMENTS", "_restrictions_8h.html#a3eddf2d51c0f63466d8484306be8894e", null ],
    [ "PO_BROKEN_LIST_PARSING", "_restrictions_8h.html#a97bc649950875191a1fe21b479624b40", null ],
    [ "PO_BROKEN_LOGIC_PRECEDENCE", "_restrictions_8h.html#a7f95f791b947dcee3c08196de5b31e6f", null ],
    [ "PO_BROKEN_LOOP_STATEMENT", "_restrictions_8h.html#a6529d08dacb020f44aa1dc65af9bfff2", null ],
    [ "PO_BROKEN_OPERATORS", "_restrictions_8h.html#a8f864618a956ab4e269ce683d2f22faf", null ],
    [ "PO_BROKEN_RANGE", "_restrictions_8h.html#a074963cba07cc02a0e7e1ceb2bb4e2a7", null ],
    [ "PO_BROKEN_REFERENCES", "_restrictions_8h.html#a20d1a4e4e60852fe6f679895d5492937", null ],
    [ "PO_BROKEN_SPRINTF", "_restrictions_8h.html#a3bdb6d77a5bd550a82f21e1ae9d80268", null ],
    [ "PO_DEFAULT", "_restrictions_8h.html#aa29860ef8e86f49c053eb01cd5970785", null ],
    [ "PO_FREE_OPTIONS", "_restrictions_8h.html#a8c0f832463cc90cbe0cdbbc971960d04", null ],
    [ "PO_FREE_STYLE_OPTIONS", "_restrictions_8h.html#a886d7812758c2949c11f6ba8ed9ef764", null ],
    [ "PO_IN_MODULE", "_restrictions_8h.html#a12e6461a371949633ac1f7446e703048", null ],
    [ "PO_INHERITANCE_OPTIONS", "_restrictions_8h.html#a30c8182ffe5352646dda65c51c6497d1", null ],
    [ "PO_LOCK_WARNINGS", "_restrictions_8h.html#af1d6283a0f6083095c5d282cd9ace342", null ],
    [ "PO_LOCKDOWN", "_restrictions_8h.html#a1c08b472c7971d53ef60d85491bdaed9", null ],
    [ "PO_NEW_STYLE", "_restrictions_8h.html#ae841c2af8dd20a22e2a7b53042570048", null ],
    [ "PO_NO_API", "_restrictions_8h.html#acd1cf6607929a5bfc48cc24870b14560", null ],
    [ "PO_NO_CHILD_PO_RESTRICTIONS", "_restrictions_8h.html#a561311c0f5f88c6e1d4eff677713bf19", null ],
    [ "PO_NO_CLASS_DEFS", "_restrictions_8h.html#a8b35d8d51093f6dd05266bc154a4e7dd", null ],
    [ "PO_NO_CONSTANT_DEFS", "_restrictions_8h.html#aaea207ef2850b46e28ae674151204c74", null ],
    [ "PO_NO_DATABASE", "_restrictions_8h.html#a59dfc5931d0eae676a2089f8e297ad80", null ],
    [ "PO_NO_DEBUGGING", "_restrictions_8h.html#aa15196fde657a2ef7ebd7318c40f12bb", null ],
    [ "PO_NO_EMBEDDED_LOGIC", "_restrictions_8h.html#adccf8054fcef8d07014fc27bb88e6b86", null ],
    [ "PO_NO_EXTERNAL_ACCESS", "_restrictions_8h.html#ab3983de451090bf2239f2a25fe38f73d", null ],
    [ "PO_NO_EXTERNAL_INFO", "_restrictions_8h.html#a72d368402cf8e9f6c8dafb74eee28745", null ],
    [ "PO_NO_EXTERNAL_PROCESS", "_restrictions_8h.html#a1ed3a8292c999e527115dcb68933c749", null ],
    [ "PO_NO_FILESYSTEM", "_restrictions_8h.html#abad0cbc4235b102f1ecaaffdbd6ebfa8", null ],
    [ "PO_NO_GLOBAL_VARS", "_restrictions_8h.html#a2e36e5f620fdb1f1a2382d1efe052025", null ],
    [ "PO_NO_GUI", "_restrictions_8h.html#a1d44fce931d36b4e4409f488d5648f1e", null ],
    [ "PO_NO_INHERIT_GLOBAL_VARS", "_restrictions_8h.html#abd55cb2825e3f0a862e617f877dd2168", null ],
    [ "PO_NO_INHERIT_PROGRAM_DATA", "_restrictions_8h.html#af40775b2d435f6461a3326e9cc484ff5", null ],
    [ "PO_NO_INHERIT_SYSTEM_CLASSES", "_restrictions_8h.html#a8be8cea4dd7ec9eb8687d9e682bece05", null ],
    [ "PO_NO_INHERIT_SYSTEM_CONSTANTS", "_restrictions_8h.html#a45a54df35963514ce26828c900c9b3ea", null ],
    [ "PO_NO_INHERIT_SYSTEM_FUNC_VARIANTS", "_restrictions_8h.html#af658e6d81da7de9272794dc71c0732d1", null ],
    [ "PO_NO_INHERIT_SYSTEM_HASHDECLS", "_restrictions_8h.html#a770b9c0f9234fad9a0d5fb725acde714", null ],
    [ "PO_NO_INHERIT_USER_CLASSES", "_restrictions_8h.html#ab133c826fe7a2e9529e30e8049da1586", null ],
    [ "PO_NO_INHERIT_USER_CONSTANTS", "_restrictions_8h.html#a51aa0fd43b74349a9204ae4e69d18cd8", null ],
    [ "PO_NO_INHERIT_USER_FUNC_VARIANTS", "_restrictions_8h.html#a68c67e66c5fb2041a598f46ade856573", null ],
    [ "PO_NO_INHERIT_USER_HASHDECLS", "_restrictions_8h.html#a29b2684994e069edf8d7048aee3e815c", null ],
    [ "PO_NO_IO", "_restrictions_8h.html#af1243d2900dbe34d3449134059d19393", null ],
    [ "PO_NO_LOCALE_CONTROL", "_restrictions_8h.html#a07a11f2168014dbb3583cbb008627336", null ],
    [ "PO_NO_MODULES", "_restrictions_8h.html#a8ba741a507c7ef6dd177574ea7b69b4c", null ],
    [ "PO_NO_NAMESPACE_DEFS", "_restrictions_8h.html#a16733571d13cb9ca375fe81b6f8f8d5e", null ],
    [ "PO_NO_NETWORK", "_restrictions_8h.html#a10a7a876290b7db60373b385c84e2b2c", null ],
    [ "PO_NO_NEW", "_restrictions_8h.html#a58296bea17ebf1413f097197a47e1201", null ],
    [ "PO_NO_PROCESS_CONTROL", "_restrictions_8h.html#af04c9ca44fb8283e3a93cbc00a0cdd9c", null ],
    [ "PO_NO_REFLECTION", "_restrictions_8h.html#aeb6b58dc32d5a70a9c40cffe8f135164", null ],
    [ "PO_NO_SUBROUTINE_DEFS", "_restrictions_8h.html#a5502e33cad308e81493e596589550afd", null ],
    [ "PO_NO_SYSTEM_API", "_restrictions_8h.html#ab541ab4240125bc9d690272469504675", null ],
    [ "PO_NO_TERMINAL_IO", "_restrictions_8h.html#aaaef27fa15c565cf9d24844838246d33", null ],
    [ "PO_NO_THREAD_CLASSES", "_restrictions_8h.html#a93cd5b824a585af6c31e687e9e065058", null ],
    [ "PO_NO_THREAD_CONTROL", "_restrictions_8h.html#afcd810858334ffcf57d20cf6ed5ccac3", null ],
    [ "PO_NO_THREAD_INFO", "_restrictions_8h.html#aa80b1d4932a471a343ffbc7494ae88e4", null ],
    [ "PO_NO_THREADS", "_restrictions_8h.html#a1e7e664d3055d0c361f6c8fb179174f4", null ],
    [ "PO_NO_TOP_LEVEL_STATEMENTS", "_restrictions_8h.html#a11d2724d7e2a46c0527f5434e4c6d93e", null ],
    [ "PO_NO_TRANSIENT", "_restrictions_8h.html#a5f8371658499be807982a79325577838", null ],
    [ "PO_NO_UNCONTROLLED_APIS", "_restrictions_8h.html#a04b2233f363e4f4c09d48305553d00ef", null ],
    [ "PO_NO_USER_API", "_restrictions_8h.html#a4a63d2f23a687c7a92e08a571725e81e", null ],
    [ "PO_POSITIVE_OPTIONS", "_restrictions_8h.html#a6b930298bc8fe27a2447159282b2b629", null ],
    [ "PO_REQUIRE_BARE_REFS", "_restrictions_8h.html#af11f1b7df14cb1468a4837d1572d8853", null ],
    [ "PO_REQUIRE_OUR", "_restrictions_8h.html#a75b1e59c3519cd7ac7dc5aa98ad89b90", null ],
    [ "PO_REQUIRE_PROTOTYPES", "_restrictions_8h.html#a7ea1ecb0e9ac1cb23def202970a99ec5", null ],
    [ "PO_REQUIRE_TYPES", "_restrictions_8h.html#a29e1813487b54afcc59a01a84e7f3d1c", null ],
    [ "PO_STRICT_ARGS", "_restrictions_8h.html#ab557b85e04e1d5eb44f843b5266dff7c", null ],
    [ "PO_STRICT_BOOLEAN_EVAL", "_restrictions_8h.html#a8f78f79e11e3dfc40903add2271eb57e", null ],
    [ "PO_STRICT_TYPES", "_restrictions_8h.html#a2b20bc9123f5fec8546f54f98461fc44", null ],
    [ "PO_STRONG_ENCAPSULATION", "_restrictions_8h.html#ae09562df3ae2b88c3f5ef1ec4a79ceb1", null ],
    [ "PO_STYLE_OPTIONS", "_restrictions_8h.html#afc7bea679488e12c045244e0231ce6a8", null ],
    [ "PO_SYSTEM_INHERITANCE_OPTIONS", "_restrictions_8h.html#a728b8373cf64adcc580806973e9d29fd", null ],
    [ "PO_SYSTEM_OPS", "_restrictions_8h.html#af6ae5a9da8d957f60bd63e84a3497197", null ],
    [ "PO_USER_INHERITANCE_OPTIONS", "_restrictions_8h.html#ab8a32efa6e09cf9c05c36a4da3328498", null ],
    [ "QDOM_DATABASE", "_restrictions_8h.html#af3533380f84f249d240684460a9291af", null ],
    [ "QDOM_DEBUGGER", "_restrictions_8h.html#ae23ea571fe599dc479fc9eb31083dc68", null ],
    [ "QDOM_DEFAULT", "_restrictions_8h.html#a26ce6266c308424920287f9da71cd524", null ],
    [ "QDOM_EMBEDDED_LOGIC", "_restrictions_8h.html#aac381340bae7ad204f78913c1c6b7b45", null ],
    [ "QDOM_EXTERNAL_INFO", "_restrictions_8h.html#a1a90042832295becc3b0d2c901a905b2", null ],
    [ "QDOM_EXTERNAL_PROCESS", "_restrictions_8h.html#a50b19ce6812e40399390eacf30a46aa3", null ],
    [ "QDOM_FILESYSTEM", "_restrictions_8h.html#a9add0f0463bc97396f7d40616d59b4c0", null ],
    [ "QDOM_GUI", "_restrictions_8h.html#aacc94472e85f38b49f1e65a66517fd66", null ],
    [ "QDOM_IN_MODULE", "_restrictions_8h.html#a9dd22458662f21465e77728c9f4c307e", null ],
    [ "QDOM_INJECTION", "_restrictions_8h.html#aad5a5b48b25980869d022e334e56f107", null ],
    [ "QDOM_LOCALE_CONTROL", "_restrictions_8h.html#a3678bcb5f709474c6962277d0bd73a8d", null ],
    [ "QDOM_MODULES", "_restrictions_8h.html#a59588ea01ce8d9795ff97557faf63fdd", null ],
    [ "QDOM_NETWORK", "_restrictions_8h.html#a56e52f68ab80aace1af16033060a5586", null ],
    [ "QDOM_PROCESS", "_restrictions_8h.html#ae02e056ea1a514e8e2bb729213132e44", null ],
    [ "QDOM_REFLECTION", "_restrictions_8h.html#a35637a04eb31e30d37e05b5e3ecb7460", null ],
    [ "QDOM_TERMINAL_IO", "_restrictions_8h.html#a595110baae5a7009a6b3b7d9d5f62e7a", null ],
    [ "QDOM_THREAD_CLASS", "_restrictions_8h.html#a70755201f6b17fa930daf3e5c362bc59", null ],
    [ "QDOM_THREAD_CONTROL", "_restrictions_8h.html#a7d5eba55a801d770a223ba6147652050", null ],
    [ "QDOM_THREAD_INFO", "_restrictions_8h.html#a3a9a03fccbbfecdd7832c3be37307a6d", null ],
    [ "QDOM_UNCONTROLLED_API", "_restrictions_8h.html#a231fb22b03c34eacb9811209456e7ae2", null ]
];
